==> bond-0.2.9.jar: public/js/out/bond/james.js <==
// Compiled by ClojureScript 1.7.228 {}
goog.provide('bond.james');
goog.require('cljs.core');
/**
 * wrap f, returning a new fn that keeping track of its call count and arguments
 */
bond.james.spy = (function bond$james$spy(f){
var calls = cljs.core.atom.call(null,cljs.core.PersistentVector.EMPTY);
var old_f = f;
return cljs.core.with_meta.call(null,((function (calls,old_f){
return (function() { 
var G__8338__delegate = function (args){
try{var resp = cljs.core.apply.call(null,old_f,args);
cljs.core.swap_BANG_.call(null,calls,cljs.core.conj,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"args","args",1315556576),args,new cljs.core.Keyword(null,"return","return",-1891502105),resp], null));

return resp;
}catch (e8337){if((e8337 instanceof bond.james.Exception)){
var e = e8337;
cljs.core.swap_BANG_.call(null,calls,cljs.core.conj,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"args","args",1315556576),args,new cljs.core.Keyword(null,"throw","throw",-1044625833),e], null));

throw e;
} else {
throw e8337;

}
}};
var G__8338 = function (var_args){
var args = null;
if (arguments.length > 0) {
var G__8339__i = 0, G__8339__a = new Array(arguments.length -  0);
while (G__8339__i < G__8339__a.length) {G__8339__a[G__8339__i] = arguments[G__8339__i + 0]; ++G__8339__i;}
  args = new cljs.core.IndexedSeq(G__8339__a,0);
} 
return G__8338__delegate.call(this,args);};
G__8338.cljs$lang$maxFixedArity = 0;
G__8338.cljs$lang$applyTo = (function (arglist__8340){
var args = cljs.core.seq(arglist__8340);
return G__8338__delegate(args);
});
G__8338.cljs$core$IFn$_invoke$arity$variadic = G__8338__delegate;
return G__8338;
})()
;})(calls,old_f))
,new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword("bond.james","calls","bond.james/calls",1931539821),calls], null));
});
/**
 * Takes one arg, a fn that has previously been spied. Returns a seq
 *   of maps, one per call. Each map contains the keys :args and :return
 *   or :throw
 */
bond.james.calls = (function bond$james$calls(f){
return cljs.core.deref.call(null,new cljs.core.Keyword("bond.james","calls","bond.james/calls",1931539821).cljs$core$IFn$_invoke$arity$1(cljs.core.meta.call(null,f)));
});
/**
 * Takes a vector of fn vars (vars that resolve to fns). Modifies the
 *   fn to track call counts, but does not change the fn's behavior
 */
bond.james.with_spy = (function bond$james$with_spy(var_args){
var args__7207__auto__ = [];
var len__7200__auto___8345 = arguments.length;
var i__7201__auto___8346 = (0);
while(true){
if((i__7201__auto___8346 < len__7200__auto___8345)){
args__7207__auto__.push((arguments[i__7201__auto___8346]));

var G__8347 = (i__7201__auto___8346 + (1));
i__7201__auto___8346 = G__8347;
continue;
} else {
}
break;
}

var argseq__7208__auto__ = ((((3) < args__7207__auto__.length))?(new cljs.core.IndexedSeq(args__7207__auto__.slice((3)),(0))):null);
return bond.james.with_spy.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),argseq__7208__auto__);
});

bond.james.with_spy.cljs$core$IFn$_invoke$arity$variadic = (function (_AMPERSAND_form,_AMPERSAND_env,vs,body){
return cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("cljs.core","with-redefs","cljs.core/with-redefs",1134293954,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,cljs.core.vec.call(null,cljs.core.mapcat.call(null,(function (v){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [v,cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("bond.james","spy","bond.james/spy",986451910,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,v))))], null);
}),vs))),cljs.core._conj.call(null,cljs.core.List.EMPTY,cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol(null,"do","do",1686842252,null)),body)))))));
});

bond.james.with_spy.cljs$lang$maxFixedArity = (3);

bond.james.with_spy.cljs$lang$applyTo = (function (seq8341){
var G__8342 = cljs.core.first.call(null,seq8341);
var seq8341__$1 = cljs.core.next.call(null,seq8341);
var G__8343 = cljs.core.first.call(null,seq8341__$1);
var seq8341__$2 = cljs.core.next.call(null,seq8341__$1);
var G__8344 = cljs.core.first.call(null,seq8341__$2);
var seq8341__$3 = cljs.core.next.call(null,seq8341__$2);
return bond.james.with_spy.cljs$core$IFn$_invoke$arity$variadic(G__8342,G__8343,G__8344,seq8341__$3);
});

bond.james.with_spy.cljs$lang$macro = true;
/**
 * Takes a vector of fn vars and/or [fn replacement] vectors.
 * 
 *   Replaces each fn with it's replacement. If a replacement is not specified for
 *   a fn it's replaced with one that takes any number of args and returns nil.
 *   Also spies the stubbed-fn
 */
bond.james.with_stub = (function bond$james$with_stub(var_args){
var args__7207__auto__ = [];
var len__7200__auto___8352 = arguments.length;
var i__7201__auto___8353 = (0);
while(true){
if((i__7201__auto___8353 < len__7200__auto___8352)){
args__7207__auto__.push((arguments[i__7201__auto___8353]));

var G__8354 = (i__7201__auto___8353 + (1));
i__7201__auto___8353 = G__8354;
continue;
} else {
}
break;
}

var argseq__7208__auto__ = ((((3) < args__7207__auto__.length))?(new cljs.core.IndexedSeq(args__7207__auto__.slice((3)),(0))):null);
return bond.james.with_stub.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),argseq__7208__auto__);
});

bond.james.with_stub.cljs$core$IFn$_invoke$arity$variadic = (function (_AMPERSAND_form,_AMPERSAND_env,vs,body){
return cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("cljs.core","with-redefs","cljs.core/with-redefs",1134293954,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,cljs.core.vec.call(null,cljs.core.mapcat.call(null,(function (v){
if(cljs.core.vector_QMARK_.call(null,v)){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.first.call(null,v),cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("bond.james","spy","bond.james/spy",986451910,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,cljs.core.second.call(null,v)))))], null);
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [v,cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("bond.james","spy","bond.james/spy",986451910,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("cljs.core","constantly","cljs.core/constantly",119002258,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,null))))))))], null);
}
}),vs))),body)));
});

bond.james.with_stub.cljs$lang$maxFixedArity = (3);

bond.james.with_stub.cljs$lang$applyTo = (function (seq8348){
var G__8349 = cljs.core.first.call(null,seq8348);
var seq8348__$1 = cljs.core.next.call(null,seq8348);
var G__8350 = cljs.core.first.call(null,seq8348__$1);
var seq8348__$2 = cljs.core.next.call(null,seq8348__$1);
var G__8351 = cljs.core.first.call(null,seq8348__$2);
var seq8348__$3 = cljs.core.next.call(null,seq8348__$2);
return bond.james.with_stub.cljs$core$IFn$_invoke$arity$variadic(G__8349,G__8350,G__8351,seq8348__$3);
});

bond.james.with_stub.cljs$lang$macro = true;

==> bond-0.2.10.jar: public/js/out/bond/james.js <==
// Compiled by ClojureScript 1.7.228 {}
goog.provide('bond.james');
goog.require('cljs.core');
/**
 * wrap f, returning a new fn that keeping track of its call count and arguments
 */
bond.james.spy = (function bond$james$spy(f){
var calls = cljs.core.atom.call(null,cljs.core.PersistentVector.EMPTY);
var old_f = f;
return cljs.core.with_meta.call(null,((function (calls,old_f){
return (function() { 
var G__8338__delegate = function (args){
try{var resp = cljs.core.apply.call(null,old_f,args);
cljs.core.swap_BANG_.call(null,calls,cljs.core.conj,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"args","args",1315556576),args,new cljs.core.Keyword(null,"return","return",-1891502105),resp], null));

return resp;
}catch (e8337){if((e8337 instanceof Error)){
var e = e8337;
cljs.core.swap_BANG_.call(null,calls,cljs.core.conj,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"args","args",1315556576),args,new cljs.core.Keyword(null,"throw","throw",-1044625833),e], null));

throw e;
} else {
throw e8337;

}
}};
var G__8338 = function (var_args){
var args = null;
if (arguments.length > 0) {
var G__8339__i = 0, G__8339__a = new Array(arguments.length -  0);
while (G__8339__i < G__8339__a.length) {G__8339__a[G__8339__i] = arguments[G__8339__i + 0]; ++G__8339__i;}
  args = new cljs.core.IndexedSeq(G__8339__a,0);
} 
return G__8338__delegate.call(this,args);};
G__8338.cljs$lang$maxFixedArity = 0;
G__8338.cljs$lang$applyTo = (function (arglist__8340){
var args = cljs.core.seq(arglist__8340);
return G__8338__delegate(args);
});
G__8338.cljs$core$IFn$_invoke$arity$variadic = G__8338__delegate;
return G__8338;
})()
;})(calls,old_f))
,new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword("bond.james","calls","bond.james/calls",1931539821),calls], null));
});
/**
 * Takes one arg, a fn that has previously been spied. Returns a seq
 *   of maps, one per call. Each map contains the keys :args and :return
 *   or :throw
 */
bond.james.calls = (function bond$james$calls(f){
return cljs.core.deref.call(null,new cljs.core.Keyword("bond.james","calls","bond.james/calls",1931539821).cljs$core$IFn$_invoke$arity$1(cljs.core.meta.call(null,f)));
});
/**
 * Takes a vector of fn vars (vars that resolve to fns). Modifies the
 *   fn to track call counts, but does not change the fn's behavior
 */
bond.james.with_spy = (function bond$james$with_spy(var_args){
var args__7207__auto__ = [];
var len__7200__auto___8345 = arguments.length;
var i__7201__auto___8346 = (0);
while(true){
if((i__7201__auto___8346 < len__7200__auto___8345)){
args__7207__auto__.push((arguments[i__7201__auto___8346]));

var G__8347 = (i__7201__auto___8346 + (1));
i__7201__auto___8346 = G__8347;
continue;
} else {
}
break;
}

var argseq__7208__auto__ = ((((3) < args__7207__auto__.length))?(new cljs.core.IndexedSeq(args__7207__auto__.slice((3)),(0))):null);
return bond.james.with_spy.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),argseq__7208__auto__);
});

bond.james.with_spy.cljs$core$IFn$_invoke$arity$variadic = (function (_AMPERSAND_form,_AMPERSAND_env,vs,body){
return cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("cljs.core","with-redefs","cljs.core/with-redefs",1134293954,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,cljs.core.vec.call(null,cljs.core.mapcat.call(null,(function (v){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [v,cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("bond.james","spy","bond.james/spy",986451910,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,v))))], null);
}),vs))),cljs.core._conj.call(null,cljs.core.List.EMPTY,cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol(null,"do","do",1686842252,null)),body)))))));
});

bond.james.with_spy.cljs$lang$maxFixedArity = (3);

bond.james.with_spy.cljs$lang$applyTo = (function (seq8341){
var G__8342 = cljs.core.first.call(null,seq8341);
var seq8341__$1 = cljs.core.next.call(null,seq8341);
var G__8343 = cljs.core.first.call(null,seq8341__$1);
var seq8341__$2 = cljs.core.next.call(null,seq8341__$1);
var G__8344 = cljs.core.first.call(null,seq8341__$2);
var seq8341__$3 = cljs.core.next.call(null,seq8341__$2);
return bond.james.with_spy.cljs$core$IFn$_invoke$arity$variadic(G__8342,G__8343,G__8344,seq8341__$3);
});

bond.james.with_spy.cljs$lang$macro = true;
/**
 * Takes a vector of fn vars and/or [fn replacement] vectors.
 * 
 *   Replaces each fn with it's replacement. If a replacement is not specified for
 *   a fn it's replaced with one that takes any number of args and returns nil.
 *   Also spies the stubbed-fn
 */
bond.james.with_stub = (function bond$james$with_stub(var_args){
var args__7207__auto__ = [];
var len__7200__auto___8352 = arguments.length;
var i__7201__auto___8353 = (0);
while(true){
if((i__7201__auto___8353 < len__7200__auto___8352)){
args__7207__auto__.push((arguments[i__7201__auto___8353]));

var G__8354 = (i__7201__auto___8353 + (1));
i__7201__auto___8353 = G__8354;
continue;
} else {
}
break;
}

var argseq__7208__auto__ = ((((3) < args__7207__auto__.length))?(new cljs.core.IndexedSeq(args__7207__auto__.slice((3)),(0))):null);
return bond.james.with_stub.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),argseq__7208__auto__);
});

bond.james.with_stub.cljs$core$IFn$_invoke$arity$variadic = (function (_AMPERSAND_form,_AMPERSAND_env,vs,body){
return cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("cljs.core","with-redefs","cljs.core/with-redefs",1134293954,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,cljs.core.vec.call(null,cljs.core.mapcat.call(null,(function (v){
if(cljs.core.vector_QMARK_.call(null,v)){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.first.call(null,v),cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("bond.james","spy","bond.james/spy",986451910,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,cljs.core.second.call(null,v)))))], null);
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [v,cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("bond.james","spy","bond.james/spy",986451910,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,cljs.core.sequence.call(null,cljs.core.seq.call(null,cljs.core.concat.call(null,cljs.core._conj.call(null,cljs.core.List.EMPTY,new cljs.core.Symbol("cljs.core","constantly","cljs.core/constantly",119002258,null)),cljs.core._conj.call(null,cljs.core.List.EMPTY,null))))))))], null);
}
}),vs))),body)));
});

bond.james.with_stub.cljs$lang$maxFixedArity = (3);

bond.james.with_stub.cljs$lang$applyTo = (function (seq8348){
var G__8349 = cljs.core.first.call(null,seq8348);
var seq8348__$1 = cljs.core.next.call(null,seq8348);
var G__8350 = cljs.core.first.call(null,seq8348__$1);
var seq8348__$2 = cljs.core.next.call(null,seq8348__$1);
var G__8351 = cljs.core.first.call(null,seq8348__$2);
var seq8348__$3 = cljs.core.next.call(null,seq8348__$2);
return bond.james.with_stub.cljs$core$IFn$_invoke$arity$variadic(G__8349,G__8350,G__8351,seq8348__$3);
});

bond.james.with_stub.cljs$lang$macro = true;
